==> dnacentersdk-2.2.2.tar.gz: dnacentersdk-2.2.2/dnacentersdk/models/validators/v1_3_1/jsd_6099da82477b858a.py <==
# -*- coding: utf-8 -*-
"""DNA Center Deploy Template data model.

Copyright (c) 2019-2020 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from dnacentersdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidator6099Da82477B858A(object):
    """Deploy Template request schema definition."""
    def __init__(self):
        super(JSONSchemaValidator6099Da82477B858A, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "properties": {
                "forcePushTemplate": {
                "type": [
                "boolean",
                "null"
                ]
                },
                "isComposite": {
                "type": [
                "boolean",
                "null"
                ]
                },
                "mainTemplateId": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                },
                "memberTemplateDeploymentInfo": {
                "items": {},
                "type": [
                "array",
                "null"
                ]
                },
                "targetInfo": {
                "items": {
                "properties": {
                "hostName": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                },
                "id": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                },
                "params": {
                "properties": {},
                "type": [
                "object",
                "null"
                ]
                },
                "type": {
                "description":
                 "",
                "enum": [
                "MANAGED_DEVICE_IP",
                "MANAGED_DEVICE_UUID",
                "PRE_PROVISIONED_SERIAL",
                "PRE_PROVISIONED_MAC",
                "DEFAULT",
                "MANAGED_DEVICE_HOSTNAME",
                null
                ],
                "type": [
                "string",
                "null"
                ]
                }
                },
                "type": [
                "object",
                "null"
                ]
                },
                "type": [
                "array",
                "null"
                ]
                },
                "templateId": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> dnacentersdk-2.4.0.tar.gz: dnacentersdk-2.4.0/dnacentersdk/models/validators/v1_3_3/jsd_6099da82477b858a.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center Deploy Template data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from dnacentersdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidator6099Da82477B858A(object):
    """Deploy Template request schema definition."""
    def __init__(self):
        super(JSONSchemaValidator6099Da82477B858A, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "properties": {
                "forcePushTemplate": {
                "type": [
                "boolean",
                "null"
                ]
                },
                "isComposite": {
                "type": [
                "boolean",
                "null"
                ]
                },
                "mainTemplateId": {
                "type": [
                "string",
                "null"
                ]
                },
                "memberTemplateDeploymentInfo": {
                "items": {},
                "type": [
                "array",
                "null"
                ]
                },
                "targetInfo": {
                "items": {
                "properties": {
                "hostName": {
                "type": [
                "string",
                "null"
                ]
                },
                "id": {
                "type": [
                "string",
                "null"
                ]
                },
                "params": {
                "properties": {},
                "type": [
                "object",
                "null"
                ]
                },
                "type": {
                "enum": [
                "MANAGED_DEVICE_IP",
                "MANAGED_DEVICE_UUID",
                "PRE_PROVISIONED_SERIAL",
                "PRE_PROVISIONED_MAC",
                "DEFAULT",
                "MANAGED_DEVICE_HOSTNAME",
                null
                ],
                "type": [
                "string",
                "null"
                ]
                }
                },
                "type": [
                "object",
                "null"
                ]
                },
                "type": [
                "array",
                "null"
                ]
                },
                "templateId": {
                "type": [
                "string",
                "null"
                ]
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )
